import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service appflow
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonappflow.html
 */
export declare class Appflow extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Grants permission to create a login profile to be used with AppFlow flows
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/
     */
    createConnectorProfile(): this;
    /**
     * Grants permission to create an AppFlow flow
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/
     */
    createFlow(): this;
    /**
     * Grants permission to delete a login profile set up for use with AppFlow
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/
     */
    deleteConnectorProfile(): this;
    /**
     * Grants permission to delete an AppFlow flow
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/
     */
    deleteFlow(): this;
    /**
     * Grants permission to describe all fields supported by AppFlow
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/
     */
    describeConnectorFields(): this;
    /**
     * Grants permission to describe all login profiles configured in AppFlow
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/
     */
    describeConnectorProfiles(): this;
    /**
     * Grants permission to describe all connectors supported by AppFlow
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/
     */
    describeConnectors(): this;
    /**
     * Grants permission to describe all flow executions for a flow configured in AppFlow
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/
     */
    describeFlowExecution(): this;
    /**
     * Grants permission to describe all flows configured in AppFlow
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/
     */
    describeFlows(): this;
    /**
     * Grants permission to list all fields supported by AppFlow
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/
     */
    listConnectorFields(): this;
    /**
     * Grants permission to list tags for a flow
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/appflow/latest/APIReference/API_ListTagsForResource.html
     */
    listTagsForResource(): this;
    /**
     * Grants permission to run a flow configured in AppFlow
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/
     */
    runFlow(): this;
    /**
     * Grants permission to tag a flow
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/appflow/latest/APIReference/API_TagResource.html
     */
    tagResource(): this;
    /**
     * Grants permission to untag a flow
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/appflow/latest/APIReference/API_UntagResource.html
     */
    untagResource(): this;
    /**
     * Grants permission to update an AppFlow flow
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/
     */
    updateFlow(): this;
}
