import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service artifact
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsartifact.html
 */
export declare class Artifact extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Grants permission to accept an AWS agreement that has not yet been accepted by the customer account.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/artifact/latest/ug/managingagreements.html
     */
    acceptAgreement(): this;
    /**
     * Grants permission to download an AWS agreement that has not yet been accepted or a customer agreement that has been accepted by the customer account.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/artifact/latest/ug/managingagreements.html
     */
    downloadAgreement(): this;
    /**
     * Grants permission to download an AWS compliance report package.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/artifact/latest/ug/getting-started.html
     */
    get(): this;
    /**
     * Grants permission to terminate a customer agreement that was previously accepted by the customer account.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/artifact/latest/ug/managingagreements.html
     */
    terminateAgreement(): this;
}
