import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service aws-marketplace
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplacecatalog.html
 */
export declare class AwsMarketplaceCatalog extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Cancels a running change set.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_CancelChangeSet.html
     */
    cancelChangeSet(): this;
    /**
     * Complete an existing task and submit the content to the associated change.
     *
     * Access Level: Write
     *
     *
     */
    completeTask(): this;
    /**
     * Returns the details of an existing change set.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_DescribeChangeSet.html
     */
    describeChangeSet(): this;
    /**
     * Returns the details of an existing entity.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_DescribeEntity.html
     */
    describeEntity(): this;
    /**
     * Returns the details of an existing task.
     *
     * Access Level: Read
     *
     *
     */
    describeTask(): this;
    /**
     * Lists existing change sets.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_ListChangeSets.html
     */
    listChangeSets(): this;
    /**
     * Lists existing entities.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_ListEntities.html
     */
    listEntities(): this;
    /**
     * Lists existing tasks.
     *
     * Access Level: List
     *
     *
     */
    listTasks(): this;
    /**
     * Requests a new change set.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_StartChangeSet.html
     */
    startChangeSet(): this;
    /**
     * Update the content of an existing task.
     *
     * Access Level: Write
     *
     *
     */
    updateTask(): this;
}
