import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service chatbot
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awschatbot.html
 */
export declare class Chatbot extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Creates an AWS Chatbot Chime Webhook Configuration.
     *
     * Access Level: Write
     *
     *
     */
    createChimeWebhookConfiguration(): this;
    /**
     * Creates an AWS Chatbot Slack Channel Configuration.
     *
     * Access Level: Write
     *
     *
     */
    createSlackChannelConfiguration(): this;
    /**
     * Deletes an AWS Chatbot Chime Webhook Configuration.
     *
     * Access Level: Write
     *
     *
     */
    deleteChimeWebhookConfiguration(): this;
    /**
     * Deletes an AWS Chatbot Slack Channel Configuration.
     *
     * Access Level: Write
     *
     *
     */
    deleteSlackChannelConfiguration(): this;
    /**
     * Lists all AWS Chatbot Chime Webhook Configurations in an AWS Account.
     *
     * Access Level: Read
     *
     *
     */
    describeChimeWebhookConfigurations(): this;
    /**
     * Lists all AWS Chatbot Slack Channel Configurations in an AWS account.
     *
     * Access Level: Read
     *
     *
     */
    describeSlackChannelConfigurations(): this;
    /**
     * Lists all public Slack channels in the Slack workspace connected to the AWS Account onboarded with AWS Chatbot service.
     *
     * Access Level: Read
     *
     *
     */
    describeSlackChannels(): this;
    /**
     * Lists all authorized Slack workspaces connected to the AWS Account onboarded with AWS Chatbot service.
     *
     * Access Level: Read
     *
     *
     */
    describeSlackWorkspaces(): this;
    /**
     * Generate OAuth parameters to request Slack OAuth code to be used by the AWS Chatbot service.
     *
     * Access Level: Read
     *
     *
     */
    getSlackOauthParameters(): this;
    /**
     * Redeem previously generated parameters with Slack API, to acquire OAuth tokens to be used by the AWS Chatbot service.
     *
     * Access Level: Write
     *
     *
     */
    redeemSlackOauthCode(): this;
    /**
     * Updates an AWS Chatbot Chime Webhook Configuration.
     *
     * Access Level: Write
     *
     *
     */
    updateChimeWebhookConfiguration(): this;
    /**
     * Updates an AWS Chatbot Slack Channel Configuration.
     *
     * Access Level: Write
     *
     *
     */
    updateSlackChannelConfiguration(): this;
}
