import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service codeguru-reviewer
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodegurureviewer.html
 */
export declare class CodeguruReviewer extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Grants permission to associates a repository with Amazon CodeGuru Reviewer.
     *
     * Access Level: Write
     *
     *
     */
    associateRepository(): this;
    /**
     * Grants permission to perform webbased oauth handshake for 3rd party providers.
     *
     * Access Level: Read
     *
     *
     */
    createConnectionToken(): this;
    /**
     * Grants permission to describe a repository association.
     *
     * Access Level: Read
     *
     *
     */
    describeRepositoryAssociation(): this;
    /**
     * Grants permission to disassociate a repository with Amazon CodeGuru Reviewer.
     *
     * Access Level: Write
     *
     *
     */
    disassociateRepository(): this;
    /**
     * Grants permission to view pull request metrics in console.
     *
     * Access Level: Read
     *
     *
     */
    getMetricsData(): this;
    /**
     * Grants permission to list summary of repository associations.
     *
     * Access Level: List
     *
     *
     */
    listRepositoryAssociations(): this;
    /**
     * Grants permission to list 3rd party providers repositories in console.
     *
     * Access Level: Read
     *
     *
     */
    listThirdPartyRepositories(): this;
}
