import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service codestar-connections
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodestarconnections.html
 */
export declare class CodestarConnections extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Grants permission to create a Connection resource
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_CreateConnection.html
     */
    createConnection(): this;
    /**
     * Grants permission to delete a Connection resource
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_DeleteConnection.html
     */
    deleteConnection(): this;
    /**
     * Grants permission to get details about a Connection resource
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_GetConnection.html
     */
    getConnection(): this;
    /**
     * Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection
     *
     * Access Level: Read
     *
     * ${AuthZDocPage}#connections-permissions-actions-handshake
     */
    getIndividualAccessToken(): this;
    /**
     * Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection
     *
     * Access Level: Read
     *
     * ${AuthZDocPage}#connections-permissions-actions-handshake
     */
    getInstallationUrl(): this;
    /**
     * Grants permission to list Connection resources
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_ListConnections.html
     */
    listConnections(): this;
    /**
     * Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection
     *
     * Access Level: List
     *
     * ${AuthZDocPage}#connections-permissions-actions-handshake
     */
    listInstallationTargets(): this;
    /**
     * Gets the set of key-value pairs that are used to manage the resource
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_ListTagsForResource.html
     */
    listTagsForResource(): this;
    /**
     * Grants permission to pass a Connection resource to an AWS service that accepts a Connection ARN as input, such as codepipeline:CreatePipeline
     *
     * Access Level: Read
     *
     * ${AuthZDocPage}#connections-passconnection
     */
    passConnection(): this;
    /**
     * Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection
     *
     * Access Level: Read
     *
     * ${AuthZDocPage}#connections-permissions-actions-handshake
     */
    startOAuthHandshake(): this;
    /**
     * Adds to or modifies the tags of the given resource
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_TagResource.html
     */
    tagResource(): this;
    /**
     * Removes tags from an AWS resource
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_UntagResource.html
     */
    untagResource(): this;
    /**
     * Grants permission to update a Connection resource with an installation of the CodeStar Connections App
     *
     * Access Level: Write
     *
     * ${AuthZDocPage}#connections-permissions-actions-handshake
     */
    updateConnectionInstallation(): this;
    /**
     * Grants permission to use a Connection resource to call provider actions
     *
     * Access Level: Read
     *
     * ${AuthZDocPage}#connections-use
     */
    useConnection(): this;
}
