import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service dataexchange
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdataexchange.html
 */
export declare class Dataexchange extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Grants permissions to cancel a job.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-jobs.html#CancelJob
     */
    cancelJob(): this;
    /**
     * Grants permission to create an asset (for example, in a Job).
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions.html#CreateAsset
     */
    createAsset(): this;
    /**
     * Grants permission to create a data set.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets.html#CreateDataSet
     */
    createDataSet(): this;
    /**
     * Grants permissions to create a job to import or export assets.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-jobs.html#CreateJob
     */
    createJob(): this;
    /**
     * Grants permission to create a revision.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions.html#CreateRevision
     */
    createRevision(): this;
    /**
     * Grants permissions to delete an asset.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#DeleteAsset
     */
    deleteAsset(): this;
    /**
     * Grants permissions to delete a data set.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid.html#DeleteDataSet
     */
    deleteDataSet(): this;
    /**
     * Grants permissions to delete a revision.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions-revisionid.html#DeleteRevision
     */
    deleteRevision(): this;
    /**
     * Grants permissions to get information about an asset and to export it (for example, in a Job).
     *
     * Access Level: Read
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#GetAsset
     */
    getAsset(): this;
    /**
     * Grants permission to get information about a data set.
     *
     * Access Level: Read
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid.html#GetDataSet
     */
    getDataSet(): this;
    /**
     * Grants permissions to get information about a job.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-jobs.html#GetJob
     */
    getJob(): this;
    /**
     * Grants permission to get information about a revision.
     *
     * Access Level: Read
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions-revisionid.html#GetRevision
     */
    getRevision(): this;
    /**
     * Grants permissions to list the revisions of a data set.
     *
     * Access Level: List
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions.html#ListDataSetRevisions
     */
    listDataSetRevisions(): this;
    /**
     * Grants permission to list data sets for the account.
     *
     * Access Level: List
     *
     * ${APIReferenceDocPage}/v1-data-sets.html#ListDataSets
     */
    listDataSets(): this;
    /**
     * Grants permissions to list jobs for the account.
     *
     * Access Level: List
     *
     * ${APIReferenceDocPage}/v1-jobs.html#ListJobs
     */
    listJobs(): this;
    /**
     * Grants permissions to get list the assets of a revision.
     *
     * Access Level: List
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions-revisionid-assets.html#ListRevisionAssets
     */
    listRevisionAssets(): this;
    /**
     * Grants permission to list the tags that you associated with the specified resource.
     *
     * Access Level: Read
     *
     * ${APIReferenceDocPage}/tags-resource-arn.html#ListTagsForResource
     */
    listTagsForResource(): this;
    /**
     * Grants permissions to start a job.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-jobs.html#StartJob
     */
    startJob(): this;
    /**
     * Grants permission to add one or more tags to a specified resource.
     *
     * Access Level: Tagging
     *
     * ${APIReferenceDocPage}/tags-resource-arn.html#TagResource
     */
    tagResource(): this;
    /**
     * Grants permission to remove one or more tags from a specified resource.
     *
     * Access Level: Tagging
     *
     * ${APIReferenceDocPage}/tags-resource-arn.html#UntagResource
     */
    untagResource(): this;
    /**
     * Grants permissions to get update information about an asset.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#UpdateAsset
     */
    updateAsset(): this;
    /**
     * Grants permissions to update information about a data set.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid.html#UpdateDataSet
     */
    updateDataSet(): this;
    /**
     * Grants permissions to update information about a revision.
     *
     * Access Level: Write
     *
     * ${APIReferenceDocPage}/v1-data-sets-datasetid-revisions-revisionid.html#UpdateRevision
     */
    updateRevision(): this;
}
