import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service deeplens
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdeeplens.html
 */
export declare class Deeplens extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Associates the user's account with IAM roles controlling various permissions needed by AWS DeepLens for proper functionality.
     *
     * Access Level: Permissions management
     *
     *
     */
    associateServiceRoleToAccount(): this;
    /**
     * Retrieves a list of AWS DeepLens devices.
     *
     * Access Level: Read
     *
     *
     */
    batchGetDevice(): this;
    /**
     * Retrieves a list of AWS DeepLens Models.
     *
     * Access Level: Read
     *
     *
     */
    batchGetModel(): this;
    /**
     * Retrieves a list of AWS DeepLens Projects.
     *
     * Access Level: Read
     *
     *
     */
    batchGetProject(): this;
    /**
     * Creates a certificate package that is used to successfully authenticate and Register an AWS DeepLens device.
     *
     * Access Level: Write
     *
     *
     */
    createDeviceCertificates(): this;
    /**
     * Creates a new AWS DeepLens Model.
     *
     * Access Level: Write
     *
     *
     */
    createModel(): this;
    /**
     * Creates a new AWS DeepLens Project.
     *
     * Access Level: Write
     *
     *
     */
    createProject(): this;
    /**
     * Deletes an AWS DeepLens Model.
     *
     * Access Level: Write
     *
     *
     */
    deleteModel(): this;
    /**
     * Deletes an AWS DeepLens Project.
     *
     * Access Level: Write
     *
     *
     */
    deleteProject(): this;
    /**
     * Deploys an AWS DeepLens project to a registered AWS DeepLens device.
     *
     * Access Level: Write
     *
     *
     */
    deployProject(): this;
    /**
     * Begins a device de-registration workflow for a registered AWS DeepLens device.
     *
     * Access Level: Write
     *
     *
     */
    deregisterDevice(): this;
    /**
     * Retrieves the account level resources associated with the user's account.
     *
     * Access Level: Read
     *
     *
     */
    getAssociatedResources(): this;
    /**
     * Retrieves the the deployment status of a particular AWS DeepLens device, along with any associated metadata.
     *
     * Access Level: Read
     *
     *
     */
    getDeploymentStatus(): this;
    /**
     * Retrieves information about an AWS DeepLens device.
     *
     * Access Level: Read
     *
     *
     */
    getDevice(): this;
    /**
     * Retrieves an AWS DeepLens Model.
     *
     * Access Level: Read
     *
     *
     */
    getModel(): this;
    /**
     * Retrieves an AWS DeepLens Project.
     *
     * Access Level: Read
     *
     *
     */
    getProject(): this;
    /**
     * Creates a new AWS DeepLens project from a sample project template.
     *
     * Access Level: Write
     *
     *
     */
    importProjectFromTemplate(): this;
    /**
     * Retrieves a list of AWS DeepLens Deployment identifiers.
     *
     * Access Level: List
     *
     *
     */
    listDeployments(): this;
    /**
     * Retrieves a list of AWS DeepLens device identifiers.
     *
     * Access Level: List
     *
     *
     */
    listDevices(): this;
    /**
     * Retrieves a list of AWS DeepLens Model identifiers.
     *
     * Access Level: List
     *
     *
     */
    listModels(): this;
    /**
     * Retrieves a list of AWS DeepLens Project identifiers.
     *
     * Access Level: List
     *
     *
     */
    listProjects(): this;
    /**
     * Begins a device registration workflow for an AWS DeepLens device.
     *
     * Access Level: Write
     *
     *
     */
    registerDevice(): this;
    /**
     * Removes a deployed AWS DeepLens project from an AWS DeepLens device.
     *
     * Access Level: Write
     *
     *
     */
    removeProject(): this;
    /**
     * Updates an existing AWS DeepLens Project.
     *
     * Access Level: Write
     *
     *
     */
    updateProject(): this;
}
