import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service ebs
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticblockstore.html
 */
export declare class Ebs extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Grants permission to return the data of a block in an Amazon Elastic Block Store (EBS) snapshot
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/ebs/latest/APIReference/API_GetSnapshotBlock.html
     */
    getSnapshotBlock(): this;
    /**
     * Grants permission to list the block indexes and block tokens for blocks that are different between two Amazon Elastic Block Store (EBS) snapshots of the same volume/snapshot lineage
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/ebs/latest/APIReference/API_ListChangedBlocks.html
     */
    listChangedBlocks(): this;
    /**
     * Grants permission to list the block indexes and block tokens for blocks in an Amazon Elastic Block Store (EBS) snapshot.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/ebs/latest/APIReference/API_ListSnapshotBlocks.html
     */
    listSnapshotBlocks(): this;
}
