import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service execute-api
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonapigateway.html
 */
export declare class ExecuteApi extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Used to invalidate API cache upon a client request
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/apigateway/api-reference/api-gateway-caching.html
     */
    invalidateCache(): this;
    /**
     * Used to invoke an API upon a client request
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/apigateway/api-reference/how-to-call-api.html
     */
    invoke(): this;
    /**
     * ManageConnections controls access to the @connections API
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/apigateway/api-reference/apigateway-websocket-control-access-iam.html
     */
    manageConnections(): this;
}
