import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service outposts
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsoutposts.html
 */
export declare class Outposts extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Creates an Outpost
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/outposts/latest/APIReference/API_CreateOutpost.html
     */
    createOutpost(): this;
    /**
     * Gets information about the specified Outpost
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetOutpost.html
     */
    getOutpost(): this;
    /**
     * Lists the instance types for the specified Outpost
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetOutpostInstanceTypes.html
     */
    getOutpostInstanceTypes(): this;
    /**
     * List the Outposts for your AWS account
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListOutposts.html
     */
    listOutposts(): this;
    /**
     * Lists the sites for the specified AWS account
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListSites.html
     */
    listSites(): this;
}
