import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service resource-groups
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsresourcegroups.html
 */
export declare class ResourceGroups extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Creates a group with a specified name, description, and resource query.
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_CreateGroup.html
     */
    createGroup(): this;
    /**
     * Deletes a specified resource group
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_DeleteGroup.html
     */
    deleteGroup(): this;
    /**
     * Gets information of a specified resource group
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetGroup.html
     */
    getGroup(): this;
    /**
     * Gets the query associated with a specified resource group
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetGroupQuery.html
     */
    getGroupQuery(): this;
    /**
     * Gets the tags associated with a specified resource group
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetTags.html
     */
    getTags(): this;
    /**
     * Lists the resources that are member of a specified resource group
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_ListGroupResources.html
     */
    listGroupResources(): this;
    /**
     * Lists all resource groups
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_ListGroups.html
     */
    listGroups(): this;
    /**
     * Returns a list of AWS resource identifiers matching the given query
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_SearchResources.html
     */
    searchResources(): this;
    /**
     * Tags a specified resource group
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_Tag.html
     */
    tag(): this;
    /**
     * Removes tags associated with a specified resource group
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_Untag.html
     */
    untag(): this;
    /**
     * Updates a specified resource group
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_UpdateGroup.html
     */
    updateGroup(): this;
    /**
     * Updates the query associated with a specified resource group
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/ARG/latest/APIReference/API_UpdateGroupQuery.html
     */
    updateGroupQuery(): this;
}
