import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service s3
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazons3.html
 */
export declare class S3 extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Aborts a multipart upload.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html
     */
    abortMultipartUpload(): this;
    /**
     * Allows circumvention of governance-mode object retention settings
     *
     * Access Level: Permissions management
     *
     *
     */
    bypassGovernanceRetention(): this;
    /**
     * Creates a new access point.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html
     */
    createAccessPoint(): this;
    /**
     * Creates a new bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html
     */
    createBucket(): this;
    /**
     * Creates a new Amazon S3 Batch Operations job.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html
     */
    createJob(): this;
    /**
     * Deletes the access point named in the URI
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPoint.html
     */
    deleteAccessPoint(): this;
    /**
     * Delete the policy on a specified access point
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicy.html
     */
    deleteAccessPointPolicy(): this;
    /**
     * Deletes the bucket named in the URI
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html
     */
    deleteBucket(): this;
    /**
     * Delete the policy on a specified bucket
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketPolicy.html
     */
    deleteBucketPolicy(): this;
    /**
     * Removes the website configuration for a bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketWebsite.html
     */
    deleteBucketWebsite(): this;
    /**
     * Removes the null version (if there is one) of an object and inserts a delete marker, which becomes the current version of the object.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html
     */
    deleteObject(): this;
    /**
     * This implementation of the DELETE operation uses the tagging subresource to remove the entire tag set from the specified object.
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html
     */
    deleteObjectTagging(): this;
    /**
     * To remove a specific version of a object, you must be the bucket owner and you must use the versionId subresource.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html
     */
    deleteObjectVersion(): this;
    /**
     * DELETE Object tagging (for a Specific Version of the Object)
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html
     */
    deleteObjectVersionTagging(): this;
    /**
     * Retrieves the configuration parameters and status for an Amazon S3 batch operations job.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeJob.html
     */
    describeJob(): this;
    /**
     * This implementation of the GET operation uses the accelerate subresource to return the Transfer Acceleration state of a bucket, which is either Enabled or Suspended.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAccelerateConfiguration.html
     */
    getAccelerateConfiguration(): this;
    /**
     * Retrieve access point metadata
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html
     */
    getAccessPoint(): this;
    /**
     * Return the policy of a specified access point.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicy.html
     */
    getAccessPointPolicy(): this;
    /**
     * Retrieve the policy status for an specific access point's policy
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicyStatus.html
     */
    getAccessPointPolicyStatus(): this;
    /**
     * Retrieve the PublicAccessBlock configuration for an AWS account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetPublicAccessBlock.html
     */
    getAccountPublicAccessBlock(): this;
    /**
     * This implementation of the GET operation returns an analytics configuration (identified by the analytics configuration ID) from the bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAnalyticsConfiguration.html
     */
    getAnalyticsConfiguration(): this;
    /**
     * Return the access control list (ACL) of a bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAcl.html
     */
    getBucketAcl(): this;
    /**
     * Returns the CORS configuration information set for the bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketCors.html
     */
    getBucketCORS(): this;
    /**
     * Return a bucket's region.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLocation.html
     */
    getBucketLocation(): this;
    /**
     * Return the logging status of a bucket and the permissions users have to view and modify that status.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLogging.html
     */
    getBucketLogging(): this;
    /**
     * Return the notification configuration of a bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketNotification.html
     */
    getBucketNotification(): this;
    /**
     * GET Object Lock configuration for a specific bucket
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLockConfiguration.html
     */
    getBucketObjectLockConfiguration(): this;
    /**
     * Return the policy of a specified bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicy.html
     */
    getBucketPolicy(): this;
    /**
     * Retrieve the policy status for an specific S3 bucket, indicating whether the bucket is public.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicyStatus.html
     */
    getBucketPolicyStatus(): this;
    /**
     * Retrieve the PublicAccessBlock configuration for a specific S3 bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetPublicAccessBlock.html
     */
    getBucketPublicAccessBlock(): this;
    /**
     * Return the request payment configuration of a bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketRequestPayment.html
     */
    getBucketRequestPayment(): this;
    /**
     * Return the tag set associated with the bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketTagging.html
     */
    getBucketTagging(): this;
    /**
     * Return the versioning state of a bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketVersioning.html
     */
    getBucketVersioning(): this;
    /**
     * Returns the website configuration associated with a bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketWebsite.html
     */
    getBucketWebsite(): this;
    /**
     * Returns the encryption configuration information set on the bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketEncryption.html
     */
    getEncryptionConfiguration(): this;
    /**
     * This implementation of the GET operation returns an inventory configuration (identified by the inventory configuration ID) from the bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketInventoryConfiguration.html
     */
    getInventoryConfiguration(): this;
    /**
     * Returns the lifecycle configuration information set on the bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html
     */
    getLifecycleConfiguration(): this;
    /**
     * Gets a metrics configuration for the CloudWatch request metrics (specified by the metrics configuration ID) from the bucket. Note that this doesn't include the daily storage metrics.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketMetricsConfiguration.html
     */
    getMetricsConfiguration(): this;
    /**
     * Retrieves objects from Amazon S3.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html
     */
    getObject(): this;
    /**
     * Return the access control list (ACL) of an object.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html
     */
    getObjectAcl(): this;
    /**
     * GET Object Legal Hold for a specific object
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLegalHold.html
     */
    getObjectLegalHold(): this;
    /**
     * GET Object Legal Hold for a specific object
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectRetention.html
     */
    getObjectRetention(): this;
    /**
     * This implementation of the GET operation returns the tags associated with an object. You send the GET request against the tagging subresource associated with the object.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html
     */
    getObjectTagging(): this;
    /**
     * return torrent files from a bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTorrent.html
     */
    getObjectTorrent(): this;
    /**
     * To return a different version, use the versionId subresource.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html
     */
    getObjectVersion(): this;
    /**
     * To return ACL information about a different version, use the versionId subresource.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html
     */
    getObjectVersionAcl(): this;
    /**
     * Permission exercised by S3 replication
     *
     * Access Level: Read
     *
     *
     */
    getObjectVersionForReplication(): this;
    /**
     * GET Object tagging (for a Specific Version of the Object)
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html
     */
    getObjectVersionTagging(): this;
    /**
     * To return Torrent files about a different version, use the versionId subresource.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTorrent.html
     */
    getObjectVersionTorrent(): this;
    /**
     * Returns the replication configuration information set on the bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketReplication.html
     */
    getReplicationConfiguration(): this;
    /**
     * Lists access points.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPoints.html
     */
    listAccessPoints(): this;
    /**
     * Returns a list of all buckets owned by the authenticated sender of the request.
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html
     */
    listAllMyBuckets(): this;
    /**
     * Returns some or all (up to 1000) of the objects in a bucket.
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html
     */
    listBucket(): this;
    /**
     * Lists in-progress multipart uploads.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html
     */
    listBucketMultipartUploads(): this;
    /**
     * Use the versions subresource to list metadata about all of the versions of objects in a bucket.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html
     */
    listBucketVersions(): this;
    /**
     * Lists current jobs and jobs that have ended recently.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListJobs.html
     */
    listJobs(): this;
    /**
     * Lists the parts that have been uploaded for a specific multipart upload.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html
     */
    listMultipartUploadParts(): this;
    /**
     * Permission exercised by S3 replication
     *
     * Access Level: Permissions management
     *
     *
     */
    objectOwnerOverrideToBucketOwner(): this;
    /**
     * This implementation of the PUT operation uses the accelerate subresource to set the Transfer Acceleration state of an existing bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAccelerateConfiguration.html
     */
    putAccelerateConfiguration(): this;
    /**
     * Add to or replace a data policy on a access point.
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicy.html
     */
    putAccessPointPolicy(): this;
    /**
     * Create or modify the PublicAccessBlock configuration for an AWS account.
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutPublicAccessBlock.html
     */
    putAccountPublicAccessBlock(): this;
    /**
     * This implementation of the PUT operation adds an analytics configuration (identified by the analytics ID) to the bucket. You can have up to 1,000 analytics configurations per bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAnalyticsConfiguration.html
     */
    putAnalyticsConfiguration(): this;
    /**
     * Set the permissions on an existing bucket using access control lists (ACL).
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAcl.html
     */
    putBucketAcl(): this;
    /**
     * Sets the CORS configuration for your bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketCors.html
     */
    putBucketCORS(): this;
    /**
     * Set the logging parameters for a bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLogging.html
     */
    putBucketLogging(): this;
    /**
     * Enables you to receive notifications when certain events happen in your bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketNotification.html
     */
    putBucketNotification(): this;
    /**
     * PUT Object Lock configuration on a specific bucket
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectLockConfiguration.html
     */
    putBucketObjectLockConfiguration(): this;
    /**
     * Add to or replace a policy on a bucket.
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketPolicy.html
     */
    putBucketPolicy(): this;
    /**
     * Create or modify the PublicAccessBlock configuration for an specific S3 bucket.
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutPublicAccessBlock.html
     */
    putBucketPublicAccessBlock(): this;
    /**
     * Set the request payment configuration of a bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketRequestPayment.html
     */
    putBucketRequestPayment(): this;
    /**
     * Add a set of tags to an existing bucket.
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketTagging.html
     */
    putBucketTagging(): this;
    /**
     * Set the versioning state of an existing bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketVersioning.html
     */
    putBucketVersioning(): this;
    /**
     * Sets the configuration of the website that is specified in the website subresource.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketWebsite.html
     */
    putBucketWebsite(): this;
    /**
     * Sets the encryption configuration for the bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketEncryption.html
     */
    putEncryptionConfiguration(): this;
    /**
     * This implementation of the PUT operation adds an inventory configuration (identified by the inventory ID) to the bucket. You can have up to 1,000 inventory configurations per bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketInventoryConfiguration.html
     */
    putInventoryConfiguration(): this;
    /**
     * Creates a new lifecycle configuration for the bucket or replaces an existing lifecycle configuration.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html
     */
    putLifecycleConfiguration(): this;
    /**
     * Sets or updates a metrics configuration for the CloudWatch request metrics (specified by the metrics configuration ID) from the bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketMetricsConfiguration.html
     */
    putMetricsConfiguration(): this;
    /**
     * Adds an object to a bucket.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html
     */
    putObject(): this;
    /**
     * Set the access control list (ACL) permissions for an object that already exists in a bucket.
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html
     */
    putObjectAcl(): this;
    /**
     * PUT Object Legal Hold on a specific object
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectLegalHold.html
     */
    putObjectLegalHold(): this;
    /**
     * PUT Object Retention on a specific object
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectRetention.html
     */
    putObjectRetention(): this;
    /**
     * This implementation of the PUT operation uses the tagging subresource to add a set of tags to an existing object.
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html
     */
    putObjectTagging(): this;
    /**
     * The ACL of an object is set at the object version level.
     *
     * Access Level: Permissions management
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html
     */
    putObjectVersionAcl(): this;
    /**
     * PUT Object tagging (for a Specific Version of the Object)
     *
     * Access Level: Tagging
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html
     */
    putObjectVersionTagging(): this;
    /**
     * In a versioning-enabled bucket, this operation creates a new replication configuration (or replaces an existing one, if present).
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketReplication.html
     */
    putReplicationConfiguration(): this;
    /**
     * Permission exercised by S3 replication
     *
     * Access Level: Write
     *
     *
     */
    replicateDelete(): this;
    /**
     * Permission exercised by S3 replication
     *
     * Access Level: Write
     *
     *
     */
    replicateObject(): this;
    /**
     * Permission exercised by S3 replication
     *
     * Access Level: Tagging
     *
     *
     */
    replicateTags(): this;
    /**
     * Restores a temporary copy of an archived object.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_RestoreObject.html
     */
    restoreObject(): this;
    /**
     * Updates an existing job's priority.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobPriority.html
     */
    updateJobPriority(): this;
    /**
     * Updates the status for the specified job.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html
     */
    updateJobStatus(): this;
}
