import { PolicyStatement, Actions } from "./shared";
/**
 * Action provider for service wellarchitected
 *
 * https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswell-architectedtool.html
 */
export declare class Wellarchitected extends PolicyStatement {
    servicePrefix: string;
    actions: Actions;
    /**
     * Creates a new workload.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/wellarchitected/latest/userguide/define-workload.html
     */
    createWorkload(): this;
    /**
     * Shares a workload with another account.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/wellarchitected/latest/userguide/workloads-sharing.html
     */
    createWorkloadShare(): this;
    /**
     * Deletes an existing workload.
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/wellarchitected/latest/userguide/workloads-delete.html
     */
    deleteWorkload(): this;
    /**
     * Retrieves the specified workload.
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/wellarchitected/latest/userguide/workload-details.html
     */
    getWorkload(): this;
    /**
     * Lists the workloads in this account.
     *
     * Access Level: List
     *
     * https://docs.aws.amazon.com/wellarchitected/latest/userguide/workloads-page.html
     */
    listWorkloads(): this;
}
